==> haskell-wai-extra-3.1.17-100-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.17
visibility:           public
id:                   wai-extra-3.1.17-AD6FgV5uWuJ7azui80eCeO
key:                  wai-extra-3.1.17-AD6FgV5uWuJ7azui80eCeO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  239bea099b45856af9e50242f51f9782
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.17-AD6FgV5uWuJ7azui80eCeO
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    ansi-terminal-1.0.2-K3FcB9OuSW9G9IWrQwwwo4 base-4.17.2.1
    base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT
    bytestring-0.11.5.3 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7 containers-0.6.7
    cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR directory-1.3.7.1
    fast-logger-3.2.4-GrQ8nFhR5mpA8EuxDsGHQ2
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    iproute-1.7.15-8uYeoR0nR2mCWKQ6kai7pc
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP
    streaming-commons-0.2.3.0-msDAcRqGslCe0T6zzs6il text-2.0.2
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    vault-0.3.1.5-Euat3gnPaqr1JFGOFA9eru
    wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm
    wai-logger-2.5.0-62KACjarsGL324XNzO7Ya2
    warp-3.3.30-BXGJjdXXESkBepSPGuenDW
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.1.18-26-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-extra
version:              3.1.18
visibility:           public
id:                   wai-extra-3.1.18-F6kzlF5sHmSKQRA7O6iDV5
key:                  wai-extra-3.1.18-F6kzlF5sHmSKQRA7O6iDV5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  6618a09d215a73da74facf5d18e866d6
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.18
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.18
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-extra-3.1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.18-F6kzlF5sHmSKQRA7O6iDV5
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe base-4.17.2.1
    base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    bytestring-0.11.5.3 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY containers-0.6.7
    cookie-0.5.0-Khxmud11aHE2bTuo1AKBzI
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi directory-1.3.7.1
    fast-logger-3.2.4-CmUTOIzlIrP2oPyQXhvG8f
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    iproute-1.7.15-IoFRJjkKKQuBZdpOmF2qle
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl
    streaming-commons-0.2.3.0-7nYylEY3bibBf5EXMr0TCn text-2.0.2
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    vault-0.3.1.5-BHykSY1WJa8JS453tvnLdt
    wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl
    wai-logger-2.5.0-13YOrPyKsGy3LZtyMHSSJM
    warp-3.4.0-4WQzRXYOsvYHbiPfjmDm2s
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
